@@ -18,6 +18,10 @@ build_tt <- function(x, output = NULL) {
 
   x@output <- output
 
+  # apply the style_notes
+  x <- style_notes(x)
+  x <- style_caption(x)
+
   for (th in x@lazy_theme) {
     fn <- th[[1]]
     args <- th[[2]]
