@@ -1,3 +1,27 @@
+#' @exportS3Method xfun::record_print
+record_print.tinytable = function(x, ...) {
+  if (!isTRUE(check_dependency("litedown"))) {
+    return(x)
+  }
+
+  # litedown
+  fmt <- tryCatch(litedown::get_context("format"), error = function(e) NULL)
+  if (is.null(fmt)) {
+    return(x)
+  }
+
+  if (!isTRUE(fmt %in% c("latex", "markdown", "html"))) {
+    stop("tinytable in litedown only supports latex, markdown, or html output", call. = FALSE)
+  }
+
+  x <- build_tt(x, output = fmt)
+  out <- x@table_string
+
+  out <- litedown::raw_text(out, fmt)
+  return(out)
+}
+
+
 #' Print a tinytable object in knitr
 #'
 #' @keywords internal
@@ -70,18 +94,15 @@ print.tinytable <- function(x,
 
   tab <- x@table_string
 
+
   # lazy styles get evaluated here by build_tt(), at the very end
   if (output %in% c("latex", "typst", "markdown", "gfm")) {
     cat(tab, "\n")
   } else if (output == "html") {
     if (is_rstudio_notebook()) {
-      tinytable_print_rstudio <- getOption("tinytable_print_rstudio_notebook", default = "inline")
-      assert_choice(tinytable_print_rstudio, c("inline", "viewer"))
-      if (tinytable_print_rstudio == "inline") {
-        tab <- sprintf("\n```{=html}\n%s\n```\n`", tab)
-        print(knitr::asis_output(tab))
-        return(invisible(x))
-      }
+      html_kable <- htmltools_browsable(tab)
+      print(html_kable)
+      return(invisible(NULL))
     }
 
     # need to change the output directory to a temporary directory
@@ -114,3 +135,14 @@ print.tinytable <- function(x,
 setMethod("show", "tinytable", function(object) {
   print.tinytable(object, output = get_option("tinytable_print_output", default = NULL))
 })
+
+
+# adapted from {htmltools} under GPL3
+htmltools_browsable <- function(x) {
+  htmlText <- paste(enc2utf8(x), collapse = " ")
+  attr(htmlText, "html") <- TRUE
+  attr(htmlText, "browsable_html") <- TRUE
+  class(htmlText) <- c("html", "character")
+  class(htmlText) <- "shiny.tag.list"
+  htmlText
+}
