@@ -153,14 +153,16 @@ setMethod(
       if (is.null(x@theme[[1]]) || is.function(x@theme[[1]]) || isTRUE("default" %in% x@theme[[1]])) {
         x <- theme_tt(x, "default")
       }
-    } else if ("bootstrap" %in% x@theme[[1]]) {
-      x <- style_tt(x, bootstrap_class = "table")
-    } else if ("striped" %in% x@theme[[1]]) {
-      x <- style_tt(x, bootstrap_class = "table table-striped")
-    } else if ("grid" %in% x@theme[[1]]) {
-      x <- style_tt(x, bootstrap_class = "table table-bordered")
-    } else if ("void" %in% x@theme[[1]]) {
-      x <- style_tt(x, bootstrap_class = "table table-borderless")
+    } else if (is.character(x@theme[[1]])) {
+      if ("bootstrap" %in% x@theme[[1]]) {
+        x <- style_tt(x, bootstrap_class = "table")
+      } else if ("striped" %in% x@theme[[1]]) {
+        x <- style_tt(x, bootstrap_class = "table table-striped")
+      } else if ("grid" %in% x@theme[[1]]) {
+        x <- style_tt(x, bootstrap_class = "table table-bordered")
+      } else if ("void" %in% x@theme[[1]]) {
+        x <- style_tt(x, bootstrap_class = "table table-borderless")
+      }
     }
 
     if (length(x@width) > 1) {
@@ -171,8 +173,7 @@ setMethod(
     }
 
     return(x)
-  }
-)
+  })
 
 
 
