@@ -56,16 +56,6 @@ expect_snapshot_print(
 
 
 
-# bug: duplicated columns with markdown html
-dat <- data.frame(
-  markdown = c(
-    "This is _italic_ text.",
-    "This sentence ends with a superscript.^2^")
-)
-tab <- tt(dat) |>
-  format_tt(j = 1, markdown = TRUE) |>
-  style_tt(j = 1, align = "c")
-expect_snapshot_print(print_html(tab), "format_tt-vignette_html_markdown.html")
 
 
 # custom formatting
@@ -193,3 +183,55 @@ x <- tt(x) |>
   format_tt(replace = "!", quarto = TRUE) |>
   save_tt("latex")
 expect_true(grepl("IQ==", x))
+
+
+# Website scaling example
+thumbdrives <- data.frame(
+  date_lookup = as.Date(c("2024-01-15", "2024-01-18", "2024-01-14", "2024-01-16")),
+  price = c(18.49, 19.99, 24.99, 24.99),
+  price_rank = c(1, 2, 3, 3),
+  memory = c(16e9, 12e9, 10e9, 8e9),
+  speed_benchmark = c(0.6, 0.73, 0.82, 0.99)
+)
+tab <- tt(thumbdrives) |>
+  format_tt(j = 1, fn = scales::date_format("%B %y", locale = "fr")) |>
+  format_tt(j = 2, fn = scales::label_currency()) |>
+  format_tt(j = 3, fn = scales::label_ordinal()) |>
+  format_tt(j = 4, fn = scales::label_bytes()) |>
+  format_tt(j = 5, fn = scales::label_percent()) |>
+  format_tt(escape = TRUE) |>
+  print("dataframe")
+expect_true("$18.49" %in% tab$price)
+expect_true("16 GB" %in% tab$memory)
+expect_true("99%" %in% tab$speed_benchmark)
+expect_false("2024-01-15" %in% tab$date_lookup)
+
+
+# Issue #409: both NA and NaN should be replaced
+options(tinytable_format_replace = NULL)
+tab <- data.frame(x = c(1, NA, NaN, Inf))
+tab0 <- tt(tab) |> print("dataframe")
+tab1 <- tt(tab) |>
+  format_tt() |>
+  print("dataframe")
+tab2 <- tt(tab) |>
+  format_tt(replace = TRUE) |>
+  print("dataframe")
+expect_equivalent(tab0$x, c("1", "NA", "NaN", "Inf"))
+expect_equivalent(tab1$x, c("1", "NA", "NaN", "Inf"))
+expect_equivalent(tab2$x, c("1", "", "", "Inf"))
+
+
+
+
+
+# bug: duplicated columns with markdown html
+dat <- data.frame(
+  markdown = c(
+    "This is _italic_ text.",
+    "This sentence ends with a superscript.^2^")
+)
+tab <- tt(dat) |>
+  format_tt(j = 1, markdown = TRUE) |>
+  style_tt(j = 1, align = "c")
+expect_snapshot_print(print_html(tab), "format_tt-vignette_html_markdown.html")
