@@ -5,9 +5,17 @@ options(tinytable_print_output = "markdown")
 # markdown without labels
 k = iris[1:10,]
 colnames(k) <- NULL
+tt(k)
 expect_snapshot_print(
   tt(k), label = "markdown-nocolnames")
 
+# no colnames
+tab <- tt(head(iris))
+colnames(tab) <- NULL
+tab
+expect_snapshot_print(tab, label = "markdown-nocolnames_02")
+
+
 # group rows and columns
 tab <- tt(mtcars[1:10, 1:5]) |>
     group_tt(
@@ -19,6 +27,8 @@ tab <- tt(mtcars[1:10, 1:5]) |>
         "Bar" = 4:5))
 expect_snapshot_print(tab, label = "markdown-group_tt")
 
+
+
 # simple caption
 tab <- tt(mtcars[1:3, 1:3], caption = "Blah blah blah") 
 expect_snapshot_print(tab, label = "markdown-caption")
@@ -76,4 +86,11 @@ tab <- tt(x, notes = n)
 expect_snapshot_print(tab, label = "markdown-footnote")
 
 
+# GFM
+if (!is_local) exit_file("Run on Vincent's machine")
+options(tinytable_print_output = "gfm")
+expect_snapshot_print(tt(head(iris)), label = "markdown-gfm")
+
+
+# restore
 options(tinytable_print_output = NULL)
